Welcome to ClientVPS Mirrors

Help for package ig.vancouver.2014.topcolour
Version: 0.1.2.0
Date: 2015-04-27
Title: Instagram 2014 Vancouver Top Colour Dataset
Maintainer: Roland Tanglao <roland@rolandtanglao.com>
Description: A dataset of the top colours of photos from Instagram taken in 2014 in the city of Vancouver, British Columbia, Canada. It consists of: top colour and counts data. This data was obtained using the Instagram API. Instagram is a web photo sharing service. It can be found at: https://instagram.com. The Instagram API is documented at: https://instagram.com/developer/.
Depends: R (≥ 2.10)
License: CC0
Packaged: 2015-05-01 17:20:37 UTC; rolandtanglao
Author: Roland Tanglao [aut, cre]
NeedsCompilation: no
Repository: CRAN
Date/Publication: 2015-05-02 07:14:12

Instagram 2014 Vancouver dataset top colour

Description

Top Colour of all Vancouver, BC Instagram 2014 thumbnails

Usage

data("topcolour.ig.vancouver.2014")

Format

A data frame with 245736 observations on the following 2 variables: top colour and count. The top colour is the top colour from Vancouver, BC, Canada Instagram images taken in 2014.

colour

colour, in RGB Hex

count

count, the number of times that top colour occurs

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.